// saved as marginal_pseudobetasort_model.stan
data{
	int<lower=1> N;                    // Number of observations
 	int<lower=1> S;                    // Number of subjects
	int<lower=1> sub[N];               // List of subject IDs
 	int<lower=1> pair[N];              // List of pair IDs
 	int<lower=0> success[N];           // List of success counts
 	int<lower=0> attempt[N];           // List of attempt counts
}
transformed data {
 	vector[S] u;
 	for (s in 1:S) {
		u[s] = 1;
	}
}
parameters{
	matrix[7, S] z;                            // beta proxy
	real<lower=0> sigma_s[S,7];                // sigma proxy
	cholesky_factor_corr[7] L_Omega;           // prior correlation
	row_vector[7] gamma;                       // population means
	vector<lower=0>[7] tau;                    // population prior scale for means
	real<lower=0> bigsigma[7];                 // population sigma parameters
	real<lower=0,upper=1> bigbeta1;            // population mean for rando distribution
	real<lower=0> bigbeta2;                    // population sum of a1 and a2 for rando distribution
	real<lower=0,upper=1> rando[S];            // individual random errors
}
transformed parameters{
	matrix[S,7] beta;                   // individual position coefficients
	matrix[S,21] pair_p;
	real<lower=0> sigma[S,7];           // individual spread coefficients
	beta = u * gamma + (diag_pre_multiply(tau,L_Omega) * z)';
	for ( i in 1:S ) {
		for ( j in 1:7 ) {
			sigma[i,j] = sigma_s[i,j]*bigsigma[j];
		}
	}
	for ( i in 1:S ) {
		pair_p[i,1] = normal_cdf(0 , beta[i,2]-beta[i,1], sqrt(sigma[i,2]^2 + sigma[i,1]^2));
		pair_p[i,2] = normal_cdf(0 , beta[i,3]-beta[i,2], sqrt(sigma[i,3]^2 + sigma[i,2]^2));
		pair_p[i,3] = normal_cdf(0 , beta[i,4]-beta[i,3], sqrt(sigma[i,4]^2 + sigma[i,3]^2));
		pair_p[i,4] = normal_cdf(0 , beta[i,5]-beta[i,4], sqrt(sigma[i,5]^2 + sigma[i,4]^2));
		pair_p[i,5] = normal_cdf(0 , beta[i,6]-beta[i,5], sqrt(sigma[i,6]^2 + sigma[i,5]^2));
		pair_p[i,6] = normal_cdf(0 , beta[i,7]-beta[i,6], sqrt(sigma[i,7]^2 + sigma[i,6]^2));
		pair_p[i,7] = normal_cdf(0 , beta[i,3]-beta[i,1], sqrt(sigma[i,3]^2 + sigma[i,1]^2));
		pair_p[i,8] = normal_cdf(0 , beta[i,4]-beta[i,2], sqrt(sigma[i,4]^2 + sigma[i,2]^2));
		pair_p[i,9] = normal_cdf(0 , beta[i,5]-beta[i,3], sqrt(sigma[i,5]^2 + sigma[i,3]^2));
		pair_p[i,10] = normal_cdf(0, beta[i,6]-beta[i,4], sqrt(sigma[i,6]^2 + sigma[i,4]^2));
		pair_p[i,11] = normal_cdf(0, beta[i,7]-beta[i,5], sqrt(sigma[i,7]^2 + sigma[i,5]^2));
		pair_p[i,12] = normal_cdf(0, beta[i,4]-beta[i,1], sqrt(sigma[i,4]^2 + sigma[i,1]^2));
		pair_p[i,13] = normal_cdf(0, beta[i,5]-beta[i,2], sqrt(sigma[i,5]^2 + sigma[i,2]^2));
		pair_p[i,14] = normal_cdf(0, beta[i,6]-beta[i,3], sqrt(sigma[i,6]^2 + sigma[i,3]^2));
		pair_p[i,15] = normal_cdf(0, beta[i,7]-beta[i,4], sqrt(sigma[i,7]^2 + sigma[i,4]^2));
		pair_p[i,16] = normal_cdf(0, beta[i,5]-beta[i,1], sqrt(sigma[i,5]^2 + sigma[i,1]^2));
		pair_p[i,17] = normal_cdf(0, beta[i,6]-beta[i,2], sqrt(sigma[i,6]^2 + sigma[i,2]^2));
		pair_p[i,18] = normal_cdf(0, beta[i,7]-beta[i,3], sqrt(sigma[i,7]^2 + sigma[i,3]^2));
		pair_p[i,19] = normal_cdf(0, beta[i,6]-beta[i,1], sqrt(sigma[i,6]^2 + sigma[i,1]^2));
		pair_p[i,20] = normal_cdf(0, beta[i,7]-beta[i,2], sqrt(sigma[i,7]^2 + sigma[i,2]^2));
		pair_p[i,21] = normal_cdf(0, beta[i,7]-beta[i,1], sqrt(sigma[i,7]^2 + sigma[i,1]^2));
	}
}
model{
	vector[N] p;

	to_vector(z) ~ normal(0,1);
	for ( i in 1:S ) {
		for ( j in 1:7 ) {
			sigma_s[i,j] ~ exponential(1);
		}
	}

	L_Omega ~ lkj_corr_cholesky(2);
	to_vector(gamma) ~ normal(0,1);
	tau ~ exponential(5);
	bigsigma ~ cauchy(0,2);

	bigbeta1 ~ uniform(0,1);
	bigbeta2 ~ cauchy(0,1);
	rando ~ beta(bigbeta1*bigbeta2,(1-bigbeta1)*bigbeta2);

	for ( n in 1:N ) {
		p[n] = rando[sub[n]]/2 + (1-rando[sub[n]])*pair_p[sub[n],pair[n]];
	}

	success ~ binomial(attempt, p);
}
