// saved as reward_gradient_adjacent_model.stan
data{
	int<lower=1> N;                    // Number of observations
	int<lower=1> S;                    // Number of subjects
	int<lower=1> sub[N];               // List of subject IDs
	real reward[N];                    // List of reward amounts
	int<lower=0> success[N];           // List of success counts
	int<lower=0> attempt[N];           // List of attempt counts
}
transformed data {
	vector[S] u;
	for (s in 1:S) {
		u[s] = 1;
	}
}
parameters{
	matrix[2, S] z;                            // beta proxy
	cholesky_factor_corr[2] L_Omega;           // prior correlation
	vector<lower=0,upper=pi()/2>[2] tau_unif;  // tau proxy
	row_vector[2] gamma;                   // population means
}
transformed parameters{
	matrix[S,2] beta;                   // individual coefficients
	vector<lower=0>[2] tau;             // prior scale
	for ( k in 1:2 ) {
		tau[k] = 2.5 * tan(tau_unif[k]);  // Equivalent to a cauchy(0,2.5) prior
	}
	beta = u * gamma + (diag_pre_multiply(tau,L_Omega) * z)';
}
model{
	vector[N] alpha;

	to_vector(z) ~ normal(0,1);
	L_Omega ~ lkj_corr_cholesky(2);
	tau_unif ~ uniform(0,pi()/2);
	to_vector(gamma) ~ normal(0,5);

	for ( n in 1:N ) {
		alpha[n] = beta[sub[n],1] + reward[n]*beta[sub[n],2];
	}
	success ~ binomial_logit(attempt, alpha);
}
