// saved as reward_gradient_model.stan
data{
  int<lower=1> N;                    // Number of observations
  int<lower=1> S;                    // Number of subjects
  int<lower=1> sub[N];               // List of subject IDs
  real dist[N];                      // List of stimulus distances
  real reward[N];                    // List of reward amounts
  int<lower=0> success[N];           // List of success counts
  int<lower=0> attempt[N];           // List of attempt counts
}
transformed data {
  vector[S] u;
  for (s in 1:S) {
    u[s] = 1;
  }
}
parameters{
  matrix[3, S] z;                            // beta proxy
  cholesky_factor_corr[3] L_Omega;           // prior correlation
  vector<lower=0,upper=pi()/2>[3] tau_unif;  // tau proxy
  row_vector[3] gamma;                       // population means
}
transformed parameters{
  matrix[S,3] beta;                   // individual coefficients
  vector<lower=0>[3] tau;             // prior scale
  for ( k in 1:3 ) {
    tau[k] = 2.5 * tan(tau_unif[k]);  // Equivalent to a cauchy(0,2.5) prior
  }
  beta = u * gamma + (diag_pre_multiply(tau,L_Omega) * z)';
}
model{
  vector[N] alpha;

  to_vector(z) ~ normal(0,1);
  L_Omega ~ lkj_corr_cholesky(2);
  tau_unif ~ uniform(0,pi()/2);
  to_vector(gamma) ~ normal(0,5);

  for ( n in 1:N ) {
    alpha[n] = beta[sub[n],1] + dist[n]*beta[sub[n],2] + reward[n]*beta[sub[n],3];
  }
  success ~ binomial_logit(attempt, alpha);
}
